@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate test stubs for methods and functions
 
-our $VERSION = '0.0604';
+our $VERSION = '0.0700';
 
 use Moo;
 use strictures 2;
@@ -38,6 +38,13 @@ has subs => (
 );
 
 
+has is_oo => (
+    is       => 'rw',
+    init_arg => undef,
+    default  => sub { 0 },
+);
+
+
 sub gather_subs {
     my ($self) = @_;
 
@@ -68,7 +75,7 @@ sub unit_test {
             . "\n"
             . 'isa_ok $obj, "' . $self->module . '";';
     }
-    elsif ( grep { $_ eq 'new' } keys %{ $self->subs } ) {
+    elsif ( $self->is_oo ) {
         $test = 'ok $obj->can("' . $subroutine . '"), "' . $subroutine . '";';
     }
     else {
@@ -96,14 +103,19 @@ END
     $self->gather_subs;
 
     if ( exists $self->subs->{new} ) {
+        $self->is_oo(1);
+
         my $test = $self->unit_test('new');
+
         $text .= "$test\n\n";
     }
 
     for my $sub ( sort keys %{ $self->subs } ) {
         next if $sub =~ /^_/;
         next if $sub eq 'new';
+
         my $test = $self->unit_test($sub);
+
         $text .= "$test\n\n";
     }
 
@@ -127,7 +139,7 @@ Test::NaiveStubs - Generate test stubs for methods and functions
 
 =head1 VERSION
 
-version 0.0604
+version 0.0700
 
 =head1 SYNOPSIS
 
@@ -180,6 +192,12 @@ created from the B<module>.  So C<Foo::Bar> would be converted to C<foo-bar.t>.
 The subroutines in the given B<module>.  This is a computed attribute and as
 such, constructor arguments will be ignored.
 
+=head2 is_oo
+
+The subroutines contain C<new> and thus object methods are produced by the
+B<unit_test> method.  This is a computed attribute and as such, constructor
+arguments will be ignored.
+
 =head1 METHODS
 
 =head2 new()
